@@ -1,6 +1,6 @@
 /* Bitset vectors.
 
-   Copyright (C) 2001-2002, 2004-2006, 2009-2015, 2018 Free Software
+   Copyright (C) 2001-2002, 2004-2006, 2009-2015, 2018-2019 Free Software
    Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -14,7 +14,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #include <config.h>
 
@@ -22,6 +22,8 @@
 
 #include <stdlib.h>
 
+#include "xalloc.h"
+
 
 /* Create a vector of N_VECS bitsets, each of N_BITS, and of
    type TYPE.  */
@@ -29,23 +31,19 @@ bitset *
 bitsetv_alloc (bitset_bindex n_vecs, bitset_bindex n_bits,
                enum bitset_type type)
 {
-  size_t vector_bytes;
-  size_t bytes;
-  bitset *bsetv;
-  bitset_bindex i;
-
   /* Determine number of bytes for each set.  */
-  bytes = bitset_bytes (type, n_bits);
+  size_t bytes = bitset_bytes (type, n_bits);
 
   /* If size calculation overflows, memory is exhausted.  */
   if (BITSET_SIZE_MAX / (sizeof (bitset) + bytes) <= n_vecs)
     xalloc_die ();
 
   /* Allocate vector table at head of bitset array.  */
-  vector_bytes = (n_vecs + 1) * sizeof (bitset) + bytes - 1;
+  size_t vector_bytes = (n_vecs + 1) * sizeof (bitset) + bytes - 1;
   vector_bytes -= vector_bytes % bytes;
-  bsetv = xcalloc (1, vector_bytes + bytes * n_vecs);
+  bitset *bsetv = xzalloc (vector_bytes + bytes * n_vecs);
 
+  bitset_bindex i = 0;
   for (i = 0; i < n_vecs; i++)
     {
       bsetv[i] = (bitset) (void *) ((char *) bsetv + vector_bytes + i * bytes);
@@ -62,11 +60,9 @@ bitsetv_alloc (bitset_bindex n_vecs, bitset_bindex n_bits,
 /* Create a vector of N_VECS bitsets, each of N_BITS, and with
    attribute hints specified by ATTR.  */
 bitset *
-bitsetv_create (bitset_bindex n_vecs, bitset_bindex n_bits, unsigned int attr)
+bitsetv_create (bitset_bindex n_vecs, bitset_bindex n_bits, unsigned attr)
 {
-  enum bitset_type type;
-
-  type = bitset_type_choose (n_bits, attr);
+  enum bitset_type type = bitset_type_choose (n_bits, attr);
   return bitsetv_alloc (n_vecs, n_bits, type);
 }
 
@@ -75,11 +71,12 @@ bitsetv_create (bitset_bindex n_vecs, bitset_bindex n_bits, unsigned int attr)
 void
 bitsetv_free (bitsetv bsetv)
 {
-  bitset_bindex i;
-
-  for (i = 0; bsetv[i]; i++)
-      BITSET_FREE_ (bsetv[i]);
-  free (bsetv);
+  if (bsetv)
+    {
+      for (bitset_bindex i = 0; bsetv[i]; i++)
+        BITSET_FREE_ (bsetv[i]);
+      free (bsetv);
+    }
 }
 
 
@@ -87,9 +84,7 @@ bitsetv_free (bitsetv bsetv)
 void
 bitsetv_zero (bitsetv bsetv)
 {
-  bitset_bindex i;
-
-  for (i = 0; bsetv[i]; i++)
+  for (bitset_bindex i = 0; bsetv[i]; i++)
     bitset_zero (bsetv[i]);
 }
 
@@ -98,9 +93,7 @@ bitsetv_zero (bitsetv bsetv)
 void
 bitsetv_ones (bitsetv bsetv)
 {
-  bitset_bindex i;
-
-  for (i = 0; bsetv[i]; i++)
+  for (bitset_bindex i = 0; bsetv[i]; i++)
     bitset_ones (bsetv[i]);
 }
 
@@ -110,11 +103,8 @@ bitsetv_ones (bitsetv bsetv)
 void
 bitsetv_transitive_closure (bitsetv bsetv)
 {
-  bitset_bindex i;
-  bitset_bindex j;
-
-  for (i = 0; bsetv[i]; i++)
-    for (j = 0; bsetv[j]; j++)
+  for (bitset_bindex i = 0; bsetv[i]; i++)
+    for (bitset_bindex j = 0; bsetv[j]; j++)
       if (bitset_test (bsetv[j], i))
         bitset_or (bsetv[j], bsetv[j], bsetv[i]);
 }
@@ -127,10 +117,8 @@ bitsetv_transitive_closure (bitsetv bsetv)
 void
 bitsetv_reflexive_transitive_closure (bitsetv bsetv)
 {
-  bitset_bindex i;
-
   bitsetv_transitive_closure (bsetv);
-  for (i = 0; bsetv[i]; i++)
+  for (bitset_bindex i = 0; bsetv[i]; i++)
     bitset_set (bsetv[i], i);
 }
 
@@ -141,12 +129,10 @@ void
 bitsetv_dump (FILE *file, char const *title, char const *subtitle,
               bitsetv bsetv)
 {
-  bitset_windex i;
-
   fprintf (file, "%s\n", title);
-  for (i = 0; bsetv[i]; i++)
+  for (bitset_windex i = 0; bsetv[i]; i++)
     {
-      fprintf (file, "%s %lu\n", subtitle, (unsigned long int) i);
+      fprintf (file, "%s %lu\n", subtitle, (unsigned long) i);
       bitset_dump (file, bsetv[i]);
     }
 
@@ -157,13 +143,59 @@ bitsetv_dump (FILE *file, char const *title, char const *subtitle,
 void
 debug_bitsetv (bitsetv bsetv)
 {
-  bitset_windex i;
-
-  for (i = 0; bsetv[i]; i++)
+  for (bitset_windex i = 0; bsetv[i]; i++)
     {
-      fprintf (stderr, "%lu: ", (unsigned long int) i);
+      fprintf (stderr, "%lu: ", (unsigned long) i);
       debug_bitset (bsetv[i]);
     }
 
   fprintf (stderr, "\n");
 }
+
+
+/*--------------------------------------------------------.
+| Display the MATRIX array of SIZE bitsets of size SIZE.  |
+`--------------------------------------------------------*/
+
+void
+bitsetv_matrix_dump (FILE *out, const char *title, bitsetv bset)
+{
+  bitset_bindex hsize = bitset_size (bset[0]);
+
+  /* Title. */
+  fprintf (out, "%s BEGIN\n", title);
+
+  /* Column numbers. */
+  fputs ("   ", out);
+  for (bitset_bindex i = 0; i < hsize; ++i)
+    putc (i / 10 ? '0' + i / 10 : ' ', out);
+  putc ('\n', out);
+  fputs ("   ", out);
+  for (bitset_bindex i = 0; i < hsize; ++i)
+    fprintf (out, "%d", (int) (i % 10));
+  putc ('\n', out);
+
+  /* Bar. */
+  fputs ("  .", out);
+  for (bitset_bindex i = 0; i < hsize; ++i)
+    putc ('-', out);
+  fputs (".\n", out);
+
+  /* Contents. */
+  for (bitset_bindex i = 0; bset[i]; ++i)
+    {
+      fprintf (out, "%2lu|", (unsigned long) i);
+      for (bitset_bindex j = 0; j < hsize; ++j)
+        fputs (bitset_test (bset[i], j) ? "1" : " ", out);
+      fputs ("|\n", out);
+    }
+
+  /* Bar. */
+  fputs ("  `", out);
+  for (bitset_bindex i = 0; i < hsize; ++i)
+    putc ('-', out);
+  fputs ("'\n", out);
+
+  /* End title. */
+  fprintf (out, "%s END\n\n", title);
+}
