@@ -170,7 +170,7 @@ set_fderives (void)
 
 
 void
-closure_new (unsigned n)
+closure_new (int n)
 {
   itemset = xnmalloc (n, sizeof *itemset);
 
