@@ -1,6 +1,7 @@
 /* Bison Grammar Scanner
 
-   Copyright (C) 2006-2007, 2009-2013 Free Software Foundation, Inc.
+   Copyright (C) 2006-2007, 2009-2015, 2018-2019 Free Software
+   Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -20,18 +21,15 @@
 #ifndef SCAN_GRAM_H_
 # define SCAN_GRAM_H_
 
-/* From the scanner.  */
-extern FILE *gram_in;
-extern int gram__flex_debug;
-void gram_scanner_initialize (void);
+/* Initialize the scanner to read file GRAM. */
+void gram_scanner_open (const char *gram);
+/* Close the open files.  */
+void gram_scanner_close (void);
+
+/* Free all the memory allocated to the scanner. */
 void gram_scanner_free (void);
 void gram_scanner_last_string_free (void);
 
-/* These are declared by the scanner, but not used.  We put them here
-   to pacify "make syntax-check".  */
-extern FILE *gram_out;
-extern int gram_lineno;
-
 # define GRAM_LEX_DECL int gram_lex (GRAM_STYPE *val, location *loc)
 GRAM_LEX_DECL;
 
